@@ -20,7 +20,7 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.09026_02';
+our $VERSION = '0.20026_01';
 
 $VERSION =~ /([0-9]{2})$/;
 my $compat_version = $1;
@@ -83,6 +83,16 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
 
     @DEFAULT_SEARCH_PATH = split $Config{path_sep}, $ENV{PKG_CONFIG_LIBDIR};
 
+} elsif($^O eq 'msys') {
+
+    # MSYS2 seems to actually set PKG_CONFIG_PATH in its /etc/profile
+    # god bless it.  But.  The defaults if you unset the environment
+    # variable are different
+    @DEFAULT_SEARCH_PATH = qw(
+        /usr/lib/pkgconfig
+        /usr/share/pkgconfig
+    );
+
 } elsif($^O eq 'solaris' && $Config{ptrsize} == 8) {
 
     @DEFAULT_SEARCH_PATH = qw(
@@ -108,6 +118,7 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
           /usr/lib/pkgconfig/ /usr/share/pkgconfig/
         !;
     }
+
 } elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
 
     my $arch;
@@ -192,6 +203,25 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
         );
     }
 
+} elsif($^O eq 'linux' && -r "/etc/slackware-version") {
+
+    # Fetch ptrsize value
+    my $ptrsize = $Config{ptrsize};
+
+    # Are we running on 64 bit system?
+    if ($ptrsize == 8) {
+        # We do
+        @DEFAULT_SEARCH_PATH = qw!
+          /usr/lib64/pkgconfig/ /usr/share/pkgconfig/
+        !;
+    } else {
+        # We're running on a 32 bit system (hopefully)
+        @DEFAULT_SEARCH_PATH = qw!
+          /usr/lib/pkgconfig/ /usr/share/pkgconfig/
+        !;
+    }
+  
+
 } elsif($^O eq 'freebsd') {
 
     # TODO: FreeBSD 10's version of pkg-config does not
@@ -240,12 +270,21 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
     require Config;
     if($Config::Config{myuname} =~ /strawberry-perl/)
     {
-        my($vol, $dir, $file) = File::Spec->splitpath($^X);
-        my @dirs = File::Spec->splitdir($dir);
-        splice @dirs, -3;
-        my $path = (File::Spec->catdir($vol, @dirs, qw( c lib pkgconfig )));
-        $path =~ s{\\}{/}g;
-        @DEFAULT_SEARCH_PATH = $path;
+        #  handle PAR::Packer executables which have $^X eq "perl.exe"
+        if ($ENV{PAR_0})
+        {
+            my $path = $ENV{PAR_TEMP};
+            $path =~ s{\\}{/}g;
+            @DEFAULT_SEARCH_PATH = ($path);
+        }
+        else {
+            my($vol, $dir, $file) = File::Spec->splitpath($^X);
+            my @dirs = File::Spec->splitdir($dir);
+            splice @dirs, -3;
+            my $path = (File::Spec->catdir($vol, @dirs, qw( c lib pkgconfig )));
+            $path =~ s{\\}{/}g;
+            @DEFAULT_SEARCH_PATH = $path;
+        }
     }
     
     my @reg_paths;
@@ -297,9 +336,9 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
         );
     }
     
-    # See caveats above for Strawberry
+    # See caveats above for Strawberry and PAR::Packer
     require Config;
-    if($Config::Config{myuname} =~ /strawberry-perl/)
+    if(not $ENV{PAR_0} and $Config::Config{myuname} =~ /strawberry-perl/)
     {
         my($vol, $dir, $file) = File::Spec->splitpath($^X);
         my @dirs = File::Spec->splitdir($dir);
@@ -413,7 +452,7 @@ struct(
      # will be listed first
      'libs_deplist' => '*%',
 
-     # cummulative cflags and ldflags
+     # cumulative cflags and ldflags
      'ldflags'   => '*@',
      'cflags'    => '*@',
 
@@ -707,7 +746,7 @@ sub parse_line {
     #perl variables can't have '.' in them:
     $field =~ s/\./DOT/g;
     
-    #remove quoutes from field names
+    #remove quotes from field names
     $field =~ s/['"]//g;
     
 
@@ -726,7 +765,7 @@ sub parse_line {
     $value = join ' ', map { s/(["'])/\\$1/g; "'$_'" } shellwords $value
       if $value =~ /[\\"']/;
     
-    #quoute the value string, unless quouted already
+    #quote the value string, unless quoted already
     $value = "\"$value\"";
     
     #get existent variables from our hash:
@@ -767,6 +806,9 @@ sub parse_pcfile {
     
 
     $self->append_cflags(  $self->_pc_var('cflags') );
+    if($self->static) {
+        $self->append_cflags( $self->_pc_var('cflags.private') );
+    }
     $self->append_ldflags( $self->_pc_var('libs') );
     if($self->static) {
         $self->append_ldflags( $self->_pc_var('libs.private') );
@@ -1090,6 +1132,9 @@ GetOptions(
     'h|help|?'      => \my $WantHelp
 ) or pod2usage(@POD_USAGE_OPTIONS);
 
+if($^O eq 'msys' && !$ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
+    $UseStatic = 1;
+}
 
 if($WantHelp) {
     pod2usage(@POD_USAGE_OPTIONS, -exitval => 0);
@@ -1150,7 +1195,7 @@ if($WantFlags) {
 }
 
 my %pc_options;
-if($PrintExists || $AtLeastVersion || $ExactVersion || $MaxVersion) {
+if($PrintExists || $AtLeastVersion || $ExactVersion || $MaxVersion || $PrintVersion) {
     $pc_options{no_recurse} = 1;
 }
 
@@ -1278,14 +1323,14 @@ PkgConfig - Pure-Perl Core-Only replacement for pkg-config
 
     $ ppkg-config --libs --cflags --static gio-2.0
 
-    #outputs (lines artifically broken up for readability):
+    #outputs (lines artificially broken up for readability):
     # -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include
     # -pthread -lgio-2.0 -lz -lresolv -lgobject-2.0
     # -lgmodule-2.0 -ldl -lgthread-2.0 -pthread -lrt -lglib-2.0
 
 C<pkg-config.pl> can be used as an alias for C<ppkg-config> on platforms that
 support it.  It can also be installed as C<pkg-config> though this is not
-recomended if your system has a native C<pkg-config>.
+recommended if your system has a native C<pkg-config>.
 
 Compare to:
     $ pkg-config --libs --cflags --static gio-2.0
@@ -1437,7 +1482,7 @@ C<--silence-errors>
 
 =head4 --short-errors
 
-Ignored, but recognized for compatability.
+Ignored, but recognized for compatibility.
 
 =head4 --errors-to-stdout
 
@@ -1482,7 +1527,7 @@ a working version that implements this feature.
 
 =head4 I<< PkgConfig->find >>
 
-    my $result = PkgConfig->find($libary, %options);
+    my $result = PkgConfig->find($library, %options);
 
 Find a library and return a result object.
 C<$library> can be either a single name of a library, or a reference to an
@@ -1664,6 +1709,14 @@ package itself (without dependencies).
 
 The original C implementation
 
+=item L<pkgconf|https://github.com/pkgconf/pkgconf>
+
+An alternative C implementation
+
+=item L<PkgConfig::LibPkgConf>
+
+Perl bindings for C<libpkgconf>, the same library that C<pkgconf> is built on.
+
 =item L<ExtUtils::PkgConfig>
 
 A wrapper around the C<pkg-config> binary that can be used in your C<Makefile.PL>
@@ -1673,10 +1726,6 @@ or C<Build.PL>.
 
 Another perl implementation of pkg-config
 
-=item L<pkgconf|https://github.com/pkgconf/pkgconf>
-
-An alternative C implementation
-
 =item L<pkg-config|https://github.com/ruby-gnome2/pkg-config>
 
 Pure Ruby implementation.
@@ -1709,6 +1758,12 @@ Other contributors include:
 
 =item Breno G. de Oliveira (garu)
 
+=item Gregor Herrmann
+
+=item Ilya Pavlov (ILUX, Ilya33)
+
+=item Shawn Laffan (SLAFFAN, shawnlaffan)
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
